@@ -176,8 +176,8 @@ age.default <- function(x,method='U238-Pb206',oerr=1,sigdig=NA,
 #' \code{PbPb} or \code{x} has class \code{UPb} and
 #' \code{3<x$format<7}); or
 #'
-#' \code{settings('iratio','Pb208Pb206')} and
-#' \code{settings('iratio','Pb208Pb207')} (if \code{x} has class
+#' \code{settings('iratio','Pb206Pb208')} and
+#' \code{settings('iratio','Pb207Pb208')} (if \code{x} has class
 #' \code{UPb} and \code{x$format=7} or \code{8}).
 #' 
 #' \code{2}: use the isochron intercept as the initial Pb-composition
@@ -373,7 +373,7 @@ age.UThHe <- function(x,isochron=FALSE,central=FALSE,i=NULL,oerr=1,sigdig=NA,...
 #' @rdname age
 #' @export
 age.fissiontracks <- function(x,central=FALSE,i=NULL,
-                              oerr=1,sigdig=NA,exterr=TRUE,...){
+                              oerr=1,sigdig=NA,exterr=FALSE,...){
     if (central){
         out <- central(x)
     } else {
