@@ -131,7 +131,7 @@
 #' @param sigdig number of significant digits for the
 #'     concordia/discordia age
 #' 
-#' @param common.Pb common lead correction:
+#' @param common.Pb common lead projection:
 #'
 #' \code{0}:none
 #'
@@ -145,7 +145,10 @@
 #' \code{settings('iratio','Pb208Pb206')} and
 #' \code{settings('iratio','Pb208Pb207')} (if \code{x$format>6}).
 #' 
-#' \code{2}: use the isochron intercept as the initial Pb-composition
+#' \code{2}: use the isochron intercept as the initial
+#' Pb-composition. If \code{show.age>1}, the data are projected along
+#' the isochron line, but the isochron itself is based on the
+#' uncorrected data.
 #'
 #' \code{3}: use the Stacey-Kramers two-stage model to infer the initial
 #' Pb-composition.
@@ -307,7 +310,8 @@ concordia_helper <- function(x=NULL,tlim=NULL,type=1,
     else X <- Pb0corr(x,option=common.Pb,omit4c=unique(c(hide,omit)))
     X2plot <- subset(X,subset=plotit)
     fit <- NULL
-    X2calc <- subset(X,subset=calcit)
+    if (show.age>1) X2calc <- x2calc
+    else X2calc <- subset(X,subset=calcit)
     if (show.age==1){
         fit <- concordia.age(X2calc,type=type,exterr=exterr)
     } else if (show.age>1){
@@ -667,15 +671,32 @@ concordia.age <- function(x,i=NULL,type=1,exterr=FALSE,...){
     }
     out
 }
+# cc is assumed to follow a wetherill or cottle format
 concordia_age_helper <- function(cc,d=diseq(),type=1,exterr=FALSE,...){
-    if (type==1) Pb206U238 <- cc$x['Pb206U238']
-    else if (type==2) Pb206U238 <- 1/cc$x['U238Pb206']
-    else if (type==3) Pb206U238 <- cc$x['Pb206U238']
-    else stop('Incorrect concordia type.')
+    v <- eigen(cc$cov)$vectors[,1]
+    slope <- v[2]/v[1]
     lower <- upper <- init <- vector()
-    lower['t'] <- 0
-    upper['t'] <- get.Pb206U238.age(x=Pb206U238,d=d)[1]
-    init['t'] <- (lower['t']+upper['t'])/2
+    U85 <- iratio('U238U235')[1]
+    l8 <- lambda('U238')[1]
+    tmin <- 0
+    tmax <- ifelse(measured.disequilibrium(d),meas.diseq.maxt(d),10000)
+    if (type==1){
+        l5 <- lambda('U235')[1]
+        if (slope>0){
+            tmid <- log(slope*l5/l8)/(l8-l5) # tangential to error ellipse
+        } else {
+            tmid <- log(-l8/(l5*slope))/(l5-l8) # normal to error ellipse
+        }
+    } else if (type==3){
+        l2 <- lambda('Th232')[1]
+        if (slope>0){
+            tmid <- log(slope*l8/l2)/(l2-l8) # tangential to error ellipse
+        } else {
+            tmid <- log(-l2/(l8*slope))/(l8-l2) # normal to error ellipse
+        }
+    } else {
+        stop('concordia_age_helper is not available for concordia type ', type)
+    }
     if (d$U48$option>0){
         if (d$U48$option==2 && (is.null(d$U48$sx) || d$U48$sx<=0)){
             stop('Zero uncertainty of measured 234/238 activity ratio')
@@ -704,12 +725,15 @@ concordia_age_helper <- function(cc,d=diseq(),type=1,exterr=FALSE,...){
         lower['PaUi'] <- 0
         upper['PaUi'] <- 20
     }
+    lower['t'] <- tmin
+    upper['t'] <- tmid
+    init['t'] <- (lower['t'] + upper['t'])/2
     fit1 <- stats::optim(init,LL.concordia.age,method='L-BFGS-B',
                          lower=lower,upper=upper,exterr=exterr,
                          cc=cc,type=type,d=d,hessian=TRUE)
-    lower['t'] <- upper['t']
-    upper['t'] <- ifelse(measured.disequilibrium(d),meas.diseq.maxt(d),5000)
-    init['t'] <- (lower['t']+upper['t'])/2
+    lower['t'] <- tmid
+    upper['t'] <- tmax
+    init['t'] <- (lower['t'] + upper['t'])/2
     fit2 <- stats::optim(init,LL.concordia.age,method='L-BFGS-B',
                          lower=lower,upper=upper,exterr=exterr,
                          cc=cc,type=type,d=d,hessian=TRUE)
@@ -838,7 +862,7 @@ LL.concordia.age <- function(pars,cc,type=1,exterr=FALSE,d=diseq(),mswd=FALSE){
         y <- age_to_terawasserburg_ratios(tt,d=D)
         cols <- c('U238Pb206','Pb207Pb206')
     } else if (type==3){
-        y <- age_to_cottle_ratios(tt,d=D)
+        y <- age_to_cottle_ratios(tt,d=D,option=1)
         cols <- c('Pb206U238','Pb208Th232')
     } else {
         stop('Incorrect concordia type.')
@@ -849,7 +873,7 @@ LL.concordia.age <- function(pars,cc,type=1,exterr=FALSE,d=diseq(),mswd=FALSE){
         l5 <- settings('lambda','U235')
         l8 <- settings('lambda','U238')
         l2 <- settings('lambda','Th232')
-        U <- settings('iratio','U238U235')
+        U85 <- settings('iratio','U238U235')[1]
         Lcov <- diag(c(l5[2],l8[2],l2[2]))^2
         J <- matrix(0,2,3)
         if (type==1){
@@ -857,9 +881,9 @@ LL.concordia.age <- function(pars,cc,type=1,exterr=FALSE,d=diseq(),mswd=FALSE){
             J[2,2] <- McL$dPb206U238dl38
         } else if (type==2){
             J[1,2] <- -McL$dPb206U238dl38/McL$Pb206U238^2
-            J[2,1] <- McL$dPb207U235dl35/(U*McL$Pb206U238)
-            J[2,2] <- -McL$dPb206U238dl38/(U*McL$Pb206U238^2)
-        } else { # type == 3
+            J[2,1] <- McL$dPb207U235dl35/(U85*McL$Pb206U238)
+            J[2,2] <- -McL$dPb206U238dl38/(U85*McL$Pb206U238^2)
+        } else { # type==3
             J[1,2] <- McL$dPb206U238dl38
             J[2,3] <- tt*exp(l2[1]*tt)
         }
